/*      SAMS (Squid Account Management System
 *      Author: Dmitry Chemerik chemerik@mail.ru
 *
 *	This program is free software; you can redistribute it and/or modify
 *	it under the terms of the GNU General Public License as published by
 *	the Free Software Foundation; either version 2 of the License, or
 *	(at your option) any later version.
 *
 *	This program is distributed in the hope that it will be useful,
 *	but WITHOUT ANY WARRANTY; without even the implied warranty of
 *	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *	GNU General Public License for more details.
 *
 *	You should have received a copy of the GNU General Public License
 *	along with this program; if not, write to the Free Software
 *	Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */
#include <string.h>
#include <stdio.h>
#include <stdlib.h>
#include <time.h>
#include <ctype.h>
#include <mysql.h>
#include <math.h>
#include <fcntl.h>
#include <sys/types.h>
#include <sys/stat.h>
#include <dirent.h>
#include <sys/un.h>
#include <unistd.h>
#include "config.h"
#include "define.h"
#include "tools.h"

int UnlinkFiles(char *path,char *filemask)
{
  DIR *dirname;
  register struct dirent *dirbuf;
  char buf[BUFFER_SIZE];

  if((dirname = opendir (path)) == NULL)
    {
      fprintf(stderr, "Can't read directory %s\n",path);
      return 1;
    }
  while ((dirbuf = readdir (dirname)) != NULL ) 
    {
       if(strstr( dirbuf->d_name, filemask )!=0) 
          { 
	    sprintf(&buf[0],"%s/%s",path,dirbuf->d_name);
            unlink(&buf[0]);
	  }  
    }
  closedir (dirname);
  return(0);
}


int SavePID(int pid, char *filename)
{
  FILE *fout;
  if((fout=fopen(filename, "wt" ))==NULL)
    {
      printf("Don't save pid file %s... Exit.\n",filename);
      return(-1);
    }
  fprintf(fout,"%d",pid);
  fclose(fout);
  return(0);
}

int TestPID(char *filename)
{
  char buf[BUFFER_SIZE];
  FILE *finp;
  pid_t pid;
    
  if((finp=fopen(filename, "rt" ))==NULL)
    {
      printf("ERROR: pid file %s is busy... Exit.\n",filename);
      return(-1);
    }
  fgets( &buf[0], BUFFER_SIZE-1, finp );
  fclose(finp);
  pid=atoi(&buf[0]);
  if(kill(pid,0)==0)
    {
      printf("ERROR: program with PID %s is running: pid = %d\n",filename,pid);
      return(-1);
    }
  
  return(0);


}
void RmPID(char *filename)
{
  unlink(filename);
}



void Str2Lower(char *str)
{
  int i;
  for(i=0;i<strlen(str);i++)
     {
       str[i]=tolower(str[i]);
     }
}

void *str2upper(char *string)
{
// char *original=string;
 while(*string)
     {
        *string=toupper(*string);
        string++;
     }
// return(original);
 return(string);
}



static char *stripws( char *str )
{
int start, end;

if( !str ) return( NULL );
    for( start=0 ; str[start]==' ' ; start++ );
    if( str[start]=='\0' )
    {
	str[0]='\0';
	return( str );
    }
    for( end=strlen( str ) ; ((str[end]==' ') || (str[end]=='\0') || (str[end]=='\n') || (str[end]=='\r')) && end>-1 ; end-- ) str[end]='\0';
    if( end<1 ) return( str );
    memmove( str, str+start, end-start );
    str[ end-start+1 ]='\0';
    return( str );
}
char *xstrdup(char *str)
{
	char *s = strdup(str);
	if (s) return s;
	abort();
	return NULL;
}

/* read config from config file */
void readconf( void )
{
	static char buf[BUFFER_SIZE], *s;
	FILE *fp=NULL;

	if((fp=fopen( CONFIG_FILE, "r" )))
	{
		while( fgets( buf, BUFFER_SIZE-1, fp ) )
		{
			/* First strip off comments */
			if((s=strchr(buf, '#')))
			{
				s[0]='\0';
			}
			/* Strip of whitespaces */
			if((s=strchr(buf, '=')))
			{
				s[0]='\0';
				s++;
				stripws(buf);
				stripws(s);

				if( !strcasecmp( buf, "sams_db" ) )
					strncpy(MYSQLDATABASE,xstrdup(s),1024);
				else if( !strcasecmp( buf, "squid_db" ) )
					strncpy(SQUIDCTRLDATABASE,xstrdup(s),1024);
				else if( !strcasecmp( buf, "mysqlhostname" ) )
					strncpy(MYSQLHOSTNAME,xstrdup(s),1024);
				else if( !strcasecmp( buf, "mysqluser" ) )
					strncpy(MYSQLUSER,xstrdup(s),1024);
				else if( !strcasecmp( buf, "mysqlpassword" ) )
					strncpy(MYSQLPASSWORD,xstrdup(s),1024);
				else if( !strcasecmp( buf, "squidcachefile" ) )
					strncpy(SQUIDCACHEFILE,xstrdup(s),1024);
				else if( !strcasecmp( buf, "squidrootdir" ) )
					strncpy(SQUIDROOTDIR,xstrdup(s),1024);
				else if( !strcasecmp( buf, "squidlogdir" ) )
					strncpy(SQUIDLOGDIR,xstrdup(s),1024);
				else if( !strcasecmp( buf, "samspath" ) )
					strncpy(SAMSPATH,xstrdup(s),1024);
				else if( !strcasecmp( buf, "squidpath" ) )
					strncpy(SQUIDPATH,xstrdup(s),1024);
				else if( !strcasecmp( buf, "squidguardlogpath" ) )
					strncpy(SQUIDGUARDLOGPATH,xstrdup(s),1024);
				else if( !strcasecmp( buf, "squidguarddbpath" ) )
					strncpy(SQUIDGUARDDBPATH,xstrdup(s),1024);
				else if( !strcasecmp( buf, "recodecommand" ) )
					strncpy(RECODECOMMAND,xstrdup(s),1024);
			}
		}
	}       
}


MYSQL *do_connect(char *host_name,char *user_name, char *password,
                   char *db_name,
		   unsigned int port_num, char *socket_name,
		   unsigned int flags)
{
  MYSQL *conn;
  if(DEBUG==1)
    {
      printf("Connected database: %s:%s user=%s \n",db_name,host_name, user_name);
    }
  conn = mysql_init(NULL);
  if(conn==NULL)
      { 
        fprintf(stderr,"mysql_init() error. no open database %s\n",db_name);
        return(NULL);
      }
  if(mysql_real_connect(conn, host_name, user_name,
		     password, db_name, 0, NULL, 0)==NULL)
      { 
        fprintf(stderr,"mysql_real_connect() error. no open database %s\n",db_name);
        return(NULL);
      }
  return(conn);
}		     
		     ;
void do_disconnect(MYSQL *conn)
{        
 mysql_close(conn);
}		   

